@@ -1,5 +1,4 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-import warnings
 from abc import ABCMeta, abstractmethod
 from collections import OrderedDict
 from typing import Sequence
@@ -7,18 +6,10 @@ from typing import Sequence
 import mmcv
 import torch
 import torch.distributed as dist
-from mmcv.runner import BaseModule
+from mmcv.runner import BaseModule, auto_fp16
 
 from mmcls.core.visualization import imshow_infos
 
-# TODO import `auto_fp16` from mmcv and delete them from mmcls
-try:
-    from mmcv.runner import auto_fp16
-except ImportError:
-    warnings.warn('auto_fp16 from mmcls will be deprecated.'
-                  'Please install mmcv>=1.1.4.')
-    from mmcls.core import auto_fp16
-
 
 class BaseClassifier(BaseModule, metaclass=ABCMeta):
     """Base class for classifiers."""
